Compute Power for a Two-Sample t-Test (Equal Sample Sizes)
Source:R/power_ttest.R
power_t_two_sample.RdThis function calculates the power for a two-sample t-test when the two groups have equal sample sizes.
R/power_ttest.R
power_t_two_sample.RdThis function calculates the power for a two-sample t-test when the two groups have equal sample sizes.